# Terraform Installer [terraform-installer, ti]  
  
command line installer for the open source version of [terraform](https://www.terraform.io/)  
  
## Installation  
  
```
pip install terraform-installer  
```  
  
### Usage  
  
```
# show help and exit  
ti -h  
  
# install or upgrade specific platform  
ti darwin_amd64  
  
# install a specific version of given platform  
ti -r 0.12.1  
```   

